dk.simongray.relmeauth

RelMeAuth: signing a user in as their website, with an account at GitHub or on a Mastodon server that the site names with rel=me.

A sign-in counts when the account that signed in is the one that the site names, and when it links back to the site. The code follows https://indieweb.org/RelMeAuth and the algorithm at https://microformats.org/wiki/relmeauth. The URLs that a user can sign in as, and their canonical form, are those of IndieAuth, from indieauth-clj.

RelMeAuth: signing a user in as their website, with an account at GitHub
or on a Mastodon server that the site names with rel=me.

A sign-in counts when the account that signed in is the one that the
site names, and when it links back to the site. The code follows
https://indieweb.org/RelMeAuth and the algorithm at
https://microformats.org/wiki/relmeauth. The URLs that a user can sign
in as, and their canonical form, are those of IndieAuth, from
indieauth-clj.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries